==> wasabiD-0.2.92.tgz: package/Action/Import.jsx <==
/*/
create by wangzy
date:2016-05-17
desc:导入功能组件
 */
let  React=require("react");
let Modal=require("../Base/Layout/Modal.jsx");
let Input=require("../Base/Form/Input.jsx");
let Button=require("../Base/button/Button.jsx");
require("../sass/Action/Import.scss");
let  Import=React.createClass({
    propTypes: {
      visible:React.PropTypes.bool,//可见性
        uploadurl:React.PropTypes.string.isRequired,//上传地址
        downloadurl:React.PropTypes.string.isRequired,//下载地址
    },
    getDefaultProps:function() {
        return{
            visible:false,
            uploadurl:"",
            downloadurl:""
        }
    },
    getInitialState:function() {
        return {
            visible:this.props.visible,
        }
    },
    onChange:function(event) {//选择文件

    },
    importHandler:function() {//执行导入事件
    },
    componentWillReceiveProps:function(nextProps) {
    this.setState({
        visible:nextProps.visible,
        url:nextProps.url,
    })
    },
    render:function()
    {
         return(   <Modal  visible={this.state.visible} width={510} height={190}>

                <div className="import-title">请导入文件</div>
                      <div className="import-section">
             <div> <Input type="text" name="filename" className="import-text"></Input></div>
                 <div>
                <input type="file" className="import-file"></input> <Button type="button" className="import-chose" title="选择本地文件"></Button>
                     </div>
                </div>
                       <div className="import-submit">
                 <Button title="确定导入" onClick={this.importHandler} style={{width:90}}></Button>
             </div>
                 <a className="import-downloadmodel" href={this.props.downloadurl}>下载模版</a>
            </Modal>);

    }

});
module .exports=Import;

==> wasabiD-0.2.983.tgz: package/Action/Import.jsx <==
/*/
create by wangzy
date:2016-05-17
desc:导入功能组件
 */
let  React=require("react");
let Modal=require("../Base/Layout/Modal.jsx");
let Input=require("../Base/Form/Input.jsx");
let Button=require("../Base/Buttons/Button.jsx");
require("../sass/Action/Import.scss");
let  Import=React.createClass({
    propTypes: {
      visible:React.PropTypes.bool,//可见性
        uploadurl:React.PropTypes.string.isRequired,//上传地址
        downloadurl:React.PropTypes.string.isRequired,//下载地址
    },
    getDefaultProps:function() {
        return{
            visible:false,
            uploadurl:"",
            downloadurl:""
        }
    },
    getInitialState:function() {
        return {
            visible:this.props.visible,
        }
    },
    onChange:function(event) {//选择文件

    },
    importHandler:function() {//执行导入事件
    },
    componentWillReceiveProps:function(nextProps) {
    this.setState({
        visible:nextProps.visible,
        url:nextProps.url,
    })
    },
    render:function()
    {
         return(   <Modal  visible={this.state.visible} width={510} height={190}>

                <div className="import-title">请导入文件</div>
                      <div className="import-section">
             <div> <Input type="text" name="filename" className="import-text"></Input></div>
                 <div>
                <input type="file" className="import-file"></input> <Button type="button" className="import-chose" title="选择本地文件"></Button>
                     </div>
                </div>
                       <div className="import-submit">
                 <Button title="确定导入" onClick={this.importHandler} style={{width:90}}></Button>
             </div>
                 <a className="import-downloadmodel" href={this.props.downloadurl}>下载模版</a>
            </Modal>);

    }

});
module .exports=Import;
